@@ -96,6 +96,13 @@ class OperationLogEntry(models.Model):
 
         return gettext("LogEntry Object")
 
+    @property
+    def operator(self):
+        if hasattr(self.user, "name"):
+            return self.user.name
+
+        return getattr(self.user, self.USERNAME_FIELD)
+
     def is_addition(self):
         return self.action_flag == ADDITION
 
